@@ -42,22 +42,22 @@ class NewsletterControllerTemplate extends \Hubzero\Component\AdminController
 	{
 		//set layout
 		$this->view->setLayout('display');
-		
+
 		//get the templates
 		$newsletterTemplate = new NewsletterTemplate( $this->database );
 		$this->view->templates = $newsletterTemplate->getTemplates();
-		
+
 		// Set any errors
 		if ($this->getError())
 		{
 			$this->view->setError($this->getError());
 		}
-		
+
 		// Output the HTML
 		$this->view->display();
 	}
-	
-	
+
+
 	/**
 	 * Add Newsletter Template Task
 	 *
@@ -67,8 +67,8 @@ class NewsletterControllerTemplate extends \Hubzero\Component\AdminController
 	{
 		$this->editTask();
 	}
-	
-	
+
+
 	/**
 	 * Edit Newsletter Template Task
 	 *
@@ -78,8 +78,8 @@ class NewsletterControllerTemplate extends \Hubzero\Component\AdminController
 	{
 		//force edit layout
 		$this->view->setLayout('edit');
-		
-		//default object 
+
+		//default object
 		$this->view->template 							= new stdClass;
 		$this->view->template->id 						= null;
 		$this->view->template->editable					= null;
@@ -89,46 +89,46 @@ class NewsletterControllerTemplate extends \Hubzero\Component\AdminController
 		$this->view->template->secondary_title_color 	= null;
 		$this->view->template->secondary_text_color 	= null;
 		$this->view->template->template 				= null;
-		
+
 		//get request vars
 		$ids = JRequest::getVar("id", array());
 		$id = (isset($ids[0])) ? $ids[0] : null;
-		
+
 		//are we editing or adding a new tempalte
 		if ($id)
 		{
 			$newsletterTemplate = new NewsletterTemplate( $this->database );
 			$this->view->template = $newsletterTemplate->getTemplates( $id );
 		}
-		
+
 		//check to see if tempalte is editable
 		if ($this->view->template->editable == 0 && $this->view->template->editable != null)
 		{
-			$this->setError('This template is not an editable template.');
+			$this->setError(JText::_('COM_NEWSLETTER_TEMPLATE_NOT_EDITABLE'));
 			$this->displayTask();
 			return;
 		}
-		
+
 		//make sure were not passing in a template from save or duplicate
 		if ($this->template)
 		{
 			$this->view->template = $this->template;
 		}
-		
+
 		//set errors if we have any
 		if ($this->getError())
 		{
 			$this->view->setError($this->getError());
 		}
-		
+
 		//set vars for view
 		$this->view->config = $this->config;
-		
+
 		// Output the HTML
 		$this->view->display();
 	}
-	
-	
+
+
 	/**
 	 * Save Newsletter Template Task
 	 *
@@ -136,29 +136,32 @@ class NewsletterControllerTemplate extends \Hubzero\Component\AdminController
 	 */
 	public function saveTask()
 	{
+		// Check for request forgeries
+		JRequest::checkToken() or jexit('Invalid Token');
+
 		//get request vars
 		$template = JRequest::getVar("template", array(), 'post', 'ARRAY', JREQUEST_ALLOWHTML);
-		
+
 		//instantiate newsletter template object
 		$newsletterTemplate = new NewsletterTemplate( $this->database );
-		
-		//save the story 
+
+		//save the story
 		if (!$newsletterTemplate->save( $template ))
 		{
 			//send back template object
 			$this->template = $newsletterTemplate;
-			
+
 			$this->setError( $newsletterTemplate->getError() );
 			$this->editTask();
 			return;
 		}
-		
+
 		//inform user of successful save and redirect
-		$this->_message = JText::_('Campaign Template Successfully Saved');
+		$this->_message = JText::_('COM_NEWSLETTER_TEMPLATE_SAVED_SUCCESS');
 		$this->_redirect = 'index.php?option=com_newsletter&controller=template';
 	}
-	
-	
+
+
 	/**
 	 * Delete Task
 	 *
@@ -168,7 +171,7 @@ class NewsletterControllerTemplate extends \Hubzero\Component\AdminController
 	{
 		//get the request vars
 		$ids = JRequest::getVar("id", array());
-		
+
 		//make sure we have ids
 		if (isset($ids) && count($ids) > 0)
 		{
@@ -178,36 +181,36 @@ class NewsletterControllerTemplate extends \Hubzero\Component\AdminController
 				//instantiate template object
 				$newsletterTemplate = new NewsletterTemplate( $this->database );
 				$newsletterTemplate->load( $id );
-				
+
 				//check to make sure this isnt our default templates
 				if ($newsletterTemplate->editable == 0)
 				{
-					$this->setError('Unable to delete newsletter template.');
+					$this->setError(JText::_('COM_NEWSLETTER_TEMPLATE_DELETE_FAILED'));
 					$this->displayTask();
 					return;
 				}
-				
+
 				//mark as deleted
 				$newsletterTemplate->deleted = 1;
-				
+
 				//save template marking as deleted
 				if (!$newsletterTemplate->save( $newsletterTemplate ))
 				{
-					$this->setError('Unable to delete newsletter template.');
+					$this->setError(JText::_('COM_NEWSLETTER_TEMPLATE_DELETE_FAILED'));
 					$this->displayTask();
 					return;
 				}
 			}
 		}
-		
+
 		//set success message
-		$this->_message = JText::_('Template(s) Successfully Deleted');
-		
+		$this->_message = JText::_('COM_NEWSLETTER_TEMPLATE_DELETE_SUCCESS');
+
 		//redirect back to campaigns list
 		$this->_redirect = 'index.php?option=com_newsletter&controller=template';
 	}
-	
-	
+
+
 	/**
 	 * Duplicate Task
 	 *
@@ -218,14 +221,14 @@ class NewsletterControllerTemplate extends \Hubzero\Component\AdminController
 		//get request vars
 		$ids = JRequest::getVar("id", array());
 		$id = (isset($ids[0])) ? $ids[0] : null;
-		
+
 		//are we editing or adding a new tempalte
 		if ($id)
 		{
 			//get template we want to duplicate
 			$newsletterTemplate = new NewsletterTemplate( $this->database );
 			$template = $newsletterTemplate->getTemplates( $id );
-			
+
 			//set var so edit task can use
 			$new_template 							= new stdClass;
 			$new_template->id 						= null;
@@ -237,21 +240,21 @@ class NewsletterControllerTemplate extends \Hubzero\Component\AdminController
 			$new_template->secondary_text_color 	= $template->secondary_text_color;
 			$new_template->template 				= $template->template;
 		}
-		
+
 		//save copied template
 		$newsletterTemplate = new NewsletterTemplate( $this->database );
 		if (!$newsletterTemplate->save( $new_template ))
 		{
-			$this->setError('An error occurred while trying to duplicate the newsletter template.');
+			$this->setError(JText::_('COM_NEWSLETTER_TEMPLATE_DUPLICATE_FAILED'));
 			$this->displayTask();
 			return;
 		}
 		//set success message & redirect
-		$this->_message = JText::_('Newsletter template successfully copied.');
+		$this->_message = JText::_('COM_NEWSLETTER_TEMPLATE_DUPLICATE_SUCCESS');
 		$this->_redirect = 'index.php?option=com_newsletter&controller=template';
 	}
-	
-	
+
+
 	/**
 	 * Cancel Task
 	 *
