@@ -85,37 +85,25 @@ $link = rtrim($juri->base(), '/') . '/' . ltrim(JRoute::_($this->question->link(
 		table { border-collapse: collapse; mso-table-lspace: 0pt; mso-table-rspace: 0pt; }
 
 		@media only screen and (max-device-width: 480px) {
-			/*body { -webkit-text-size-adjust: 140% !important; }*/
-			/* Step 1: Reset colors */
-			a[href^="tel"], a[href^="sms"] {
-				text-decoration: none;
-				color: #333; /* or whatever your want */
-				pointer-events: none;
-				cursor: default;
+			body {
+				-webkit-text-size-adjust: 100% !important;
+				-ms-text-size-adjust: 100% !important;
+				font-size: 100% !important;
 			}
-			/* Step 2: Set colors for inteded items */
-			.mobile_link a[href^="tel"], .mobile_link a[href^="sms"] {
-				text-decoration: default;
-				color: #0fa1ca !important;
-				pointer-events: auto;
-				cursor: default;
+			table.tbl-wrap,
+			table.tbl-wrap td.tbl-body {
+				width: auto !important;
+				margin: 0 2em !important;
+			}
+			table.tbl-header td {
+				width: auto !important;
+			}
+			td.tbl-body .mobilehide {
+				display: none !important;
 			}
 		}
 		@media only screen and (min-device-width: 768px) and (max-device-width: 1024px) {
 			/* tablets, smaller screens, etc */
-			/* Step 1a: Repeating for the iPad */
-			a[href^="tel"], a[href^="sms"] {
-				text-decoration: none;
-				color: #333;
-				pointer-events: none;
-				cursor: default;
-			}
-			.mobile_link a[href^="tel"], .mobile_link a[href^="sms"] {
-				text-decoration: default;
-				color: #0fa1ca !important;
-				pointer-events: auto;
-				cursor: default;
-			}
 		}
 		</style>
 
@@ -145,14 +133,14 @@ $link = rtrim($juri->base(), '/') . '/' . ltrim(JRoute::_($this->question->link(
 					<td bgcolor="#ffffff" align="center" style="border-collapse: collapse;">
 
 						<!-- Start Content Wrapper Table -->
-						<table width="670" cellpadding="0" cellspacing="0" border="0" style="border-collapse: collapse;">
+						<table class="tbl-wrap" width="670" cellpadding="0" cellspacing="0" border="0" style="border-collapse: collapse;">
 							<tbody>
 								<tr style="border-collapse: collapse;">
 									<td bgcolor="#ffffff" width="10" style="border-collapse: collapse;"></td>
-									<td bgcolor="#ffffff" width="650" align="left" style="border-collapse: collapse;">
+									<td class="tbl-body" bgcolor="#ffffff" width="650" align="left" style="border-collapse: collapse;">
 
 										<!-- Start Header Spacer -->
-										<table  width="650" cellpadding="0" cellspacing="0" border="0">
+										<table  width="100%" cellpadding="0" cellspacing="0" border="0">
 											<tr style="border-collapse: collapse;">
 												<td height="30" style="border-collapse: collapse;"></td>
 											</tr>
@@ -160,13 +148,13 @@ $link = rtrim($juri->base(), '/') . '/' . ltrim(JRoute::_($this->question->link(
 										<!-- End Header Spacer -->
 
 										<!-- Start Header -->
-										<table cellpadding="2" cellspacing="3" border="0" width="100%" style="border-collapse: collapse; border-bottom: 2px solid #e1e1e1;">
+										<table class="tbl-header" cellpadding="2" cellspacing="3" border="0" width="100%" style="border-collapse: collapse; border-bottom: 2px solid #e1e1e1;">
 											<tbody>
 												<tr>
 													<td width="10%" nowrap="nowrap" align="left" valign="bottom" style="font-size: 1.4em; color: #999; padding: 0 10px 5px 0; text-align: left;">
 														<?php echo $jconfig->getValue('config.sitename'); ?>
 													</td>
-													<td width="80%" align="left" valign="bottom" style="line-height: 1; padding: 0 0 5px 10px;">
+													<td class="mobilehide" width="80%" align="left" valign="bottom" style="line-height: 1; padding: 0 0 5px 10px;">
 														<span style="font-weight: bold; font-size: 0.85em; color: #666; -webkit-text-size-adjust: none;">
 															<a href="<?php echo $juri->base(); ?>" style="color: #666; font-weight: bold; text-decoration: none; border: none;"><?php echo $juri->base(); ?></a>
 														</span>
@@ -181,14 +169,14 @@ $link = rtrim($juri->base(), '/') . '/' . ltrim(JRoute::_($this->question->link(
 										</table>
 										<!-- End Header -->
 										<!-- Start Header Spacer -->
-										<table  width="650" cellpadding="0" cellspacing="0" border="0">
+										<table  width="100%" cellpadding="0" cellspacing="0" border="0">
 											<tr style="border-collapse: collapse;">
 												<td height="30" style="border-collapse: collapse;"></td>
 											</tr>
 										</table>
 										<!-- End Header Spacer -->
 										<!-- Start Header -->
-										<table width="650" cellpadding="2" cellspacing="3" border="0" style="border-collapse: collapse;">
+										<table width="100%" cellpadding="2" cellspacing="3" border="0" style="border-collapse: collapse;">
 											<tbody>
 												<tr>
 													<td align="left" valign="bottom" style="border-collapse: collapse; color: #666; line-height: 1; padding: 5px; text-align: center;">
@@ -199,7 +187,7 @@ $link = rtrim($juri->base(), '/') . '/' . ltrim(JRoute::_($this->question->link(
 										</table>
 										<!-- End Header -->
 										<!-- Start Header Spacer -->
-										<table  width="650" cellpadding="0" cellspacing="0" border="0">
+										<table  width="100%" cellpadding="0" cellspacing="0" border="0">
 											<tr style="border-collapse: collapse;">
 												<td height="30" style="border-collapse: collapse;"></td>
 											</tr>
@@ -209,7 +197,7 @@ $link = rtrim($juri->base(), '/') . '/' . ltrim(JRoute::_($this->question->link(
 										<table id="question-info" width="100%"  cellpadding="0" cellspacing="0" border="0" style="border-collapse: collapse; line-height: 1.6em;">
 											<tbody>
 												<tr>
-													<td style="font-size: 2.5em; font-weight: bold; text-align: center; padding: 0 30px 8px 0; vertical-align: top;" align="center" valing="top">
+													<td class="mobilehide" style="font-size: 2.5em; font-weight: bold; text-align: center; padding: 0 30px 8px 0; vertical-align: top;" align="center" valing="top">
 														<p style="display: block; border: 1px solid #c8e3c2; background: #eafbe6; margin:0; padding: 1em;">?</p>
 													</td>
 													<td width="100%" style="padding: 18px 8px 8px 8px; border-top: 2px solid #e9e9e9;">
@@ -262,7 +250,7 @@ $link = rtrim($juri->base(), '/') . '/' . ltrim(JRoute::_($this->question->link(
 										</table>
 
 										<!-- Start Footer Spacer -->
-										<table width="650" cellpadding="0" cellspacing="0" border="0">
+										<table width="100%" cellpadding="0" cellspacing="0" border="0">
 											<tr style="border-collapse: collapse;">
 												<td height="30" style="border-collapse: collapse;"></td>
 											</tr>
@@ -270,11 +258,11 @@ $link = rtrim($juri->base(), '/') . '/' . ltrim(JRoute::_($this->question->link(
 										<!-- End Footer Spacer -->
 
 										<!-- Start Header -->
-										<table width="650" cellpadding="2" cellspacing="3" border="0" style="border-collapse: collapse; border-top: 2px solid #e1e1e1;">
+										<table width="100%" cellpadding="2" cellspacing="3" border="0" style="border-collapse: collapse; border-top: 2px solid #e1e1e1;">
 											<tbody>
 												<tr>
 													<td align="left" valign="bottom" style="line-height: 1; padding: 5px 0 0 0; ">
-														<span style="font-size: 0.85em; color: #666; -webkit-text-size-adjust: none;"><?php echo $jconfig->getValue('config.sitename'); ?> sent this email because you were added to the list of recipients on <a href="<?php echo $link; ?>"><?php echo $link; ?></a>. Visit our <a href="<?php echo $juri->base(); ?>/legal/privacy">Privacy Policy</a> and <a href="<?php echo $juri->base(); ?>/support">Support Center</a> if you have any questions.</span>
+														<span style="font-size: 0.85em; color: #666; -webkit-text-size-adjust: none;"><?php echo $jconfig->getValue('config.sitename'); ?> sent this email because you were added to the list of recipients on <a href="<?php echo $link; ?>">question #<?php echo $this->question->get('id'); ?></a>. Visit our <a href="<?php echo $juri->base(); ?>/legal/privacy">Privacy Policy</a> and <a href="<?php echo $juri->base(); ?>/support">Support Center</a> if you have any questions.</span>
 													</td>
 												</tr>
 											</tbody>
@@ -282,7 +270,7 @@ $link = rtrim($juri->base(), '/') . '/' . ltrim(JRoute::_($this->question->link(
 										<!-- End Header -->
 
 										<!-- Start Footer Spacer -->
-										<table width="650" cellpadding="0" cellspacing="0" border="0">
+										<table width="100%" cellpadding="0" cellspacing="0" border="0">
 											<tbody>
 												<tr style="border-collapse: collapse;">
 													<td height="30" style="border-collapse: collapse; color: #fff !important;"><div style="height: 30px !important; visibility: hidden;">----</div></td>
