@@ -103,7 +103,7 @@ if ($this->collection_id)
 
 		<label for="field_description">
 			<?php echo JText::_('COM_COLLECTIONS_ADD_DESCRIPTION'); ?>
-			<?php echo \JFactory::getEditor()->display('description', '', '', '', 35, 5, false, 'field_description', null, null, array('class' => 'minimal no-footer')); ?>
+			<?php echo $this->editor('description', '', 35, 5, 'field_description', array('class' => 'minimal no-footer')); ?>
 		</label>
 	</fieldset>
 
