@@ -305,6 +305,16 @@ class PdfFormDeployment
 		return self::find('crumb = '.self::getDbh()->quote($crumb), $section_id);
 	}
 
+	/**
+	 * Load by form id
+	 *
+	 * @return object
+	 **/
+	public static function latestFromFormId($formId, $section_id=null)
+	{
+		return self::find('form_id = ' . (int)$formId . ' ORDER BY `id` DESC');
+	}
+
 	/**
 	 * Load deployment
 	 *
@@ -318,8 +328,7 @@ class PdfFormDeployment
 
 		if (!($res = $dbh->loadAssoc()))
 		{
-			JError::raiseError(404, 'no such deployment');
-			return;
+			throw new \Hubzero\Error\Exception\RuntimeException("no such deployment");
 		}
 
 		foreach ($res as $k=>$v)
@@ -384,6 +393,16 @@ class PdfFormDeployment
 		$this->id = $id;
 	}
 
+	/**
+	 * Sets the form id
+	 *
+	 * @return void
+	 **/
+	public function setFormId($formId)
+	{
+		$this->formId = $formId;
+	}
+
 	/**
 	 * Get start time
 	 *
@@ -494,6 +513,16 @@ class PdfFormDeployment
 		return (!$this->startTime || strtotime($this->startTime) <= strtotime(JFactory::getDate())) ? 'active' : 'pending';
 	}
 
+	/**
+	 * Generates a new form deployment crumb
+	 *
+	 * @return string
+	 **/
+	public function genNewCrumb()
+	{
+		$this->crumb = str_replace(array('/', '+'), array('-', '-'), substr(base64_encode(openssl_random_pseudo_bytes(self::CRUMB_LEN + 1)), 0, self::CRUMB_LEN));
+	}
+
 	/**
 	 * Check if there are errors
 	 *
@@ -570,7 +599,7 @@ class PdfFormDeployment
 	{
 		$dep = new PdfFormDeployment;
 		$dep->formId = $fid;
-		foreach (array('startTime', 'endTime', 'resultsOpen', 'resultsClosed', 'timeLimit', 'allowedAttempts') as $key)
+		foreach (array('resultsOpen', 'resultsClosed', 'timeLimit', 'allowedAttempts') as $key)
 		{
 			if (!isset($data[$key]))
 			{
@@ -586,7 +615,7 @@ class PdfFormDeployment
 			$dep->$key = $data[$key];
 		}
 
-		$dep->crumb = str_replace(array('/', '+'), array('-', '-'), substr(base64_encode(openssl_random_pseudo_bytes(self::CRUMB_LEN + 1)), 0, self::CRUMB_LEN));
+		$dep->genNewCrumb();
 
 		return $dep;
 	}
