@@ -38,6 +38,7 @@ if ($this->course->isManager())
 {
 	$filters = array(
 		'available' => false,
+		'state'     => array(0, 1, 3),
 		'sort'      => 'publish_up',
 		'sort_Dir'  => 'DESC'
 	);
@@ -407,7 +408,7 @@ $this->css('course.css')
 								));
 								foreach ($sections as $section)
 								{
-									if ($section->params('certificate'))
+									if ($section->params('certificate') && $section->get('enrollment') != 2)
 									{
 										$cert = true;
 										break;
@@ -529,7 +530,7 @@ $this->css('course.css')
 							if (!$dflt->exists())
 							{
 								// No default? Get the first in the list
-								if (!$offering->sections()->total())
+								if (!$offering->sections($filters, true)->total())
 								{
 									$offering->makeSection();
 								}
@@ -537,8 +538,8 @@ $this->css('course.css')
 								$offering->section($dflt);
 							}
 
-							$sections = $offering->sections($filters);
-							if ($sections->total() > 0)
+							$sections = $offering->sections($filters, true);
+							if ($this->course->isManager() && $sections->total() > 0)
 							{
 								$this->view('_button')
 								     ->set('course', $this->course)
