@@ -174,6 +174,23 @@ class MembersHelperUtility
 		return(0);
 	}
 
+	/**
+	 * Validate name
+	 *
+	 * @param      string $name the name to validate
+	 * @return     integer 1 = valid, 0 = invalid
+	 */
+	public static function validname($name)
+	{
+		// Exclude all non-printable characters and the ':'
+		// ':' can mess up ldap entries
+		if (preg_match("/^[^:\p{C}]*$/u", $name))
+		{
+			return(1);
+		}
+		return(0);
+	}
+
 	/**
 	 * Validate ORCID
 	 *
