@@ -108,37 +108,32 @@ if ($this->ticket->submitter('id'))
 		table { border-collapse: collapse; mso-table-lspace: 0pt; mso-table-rspace: 0pt; }
 
 		@media only screen and (max-device-width: 480px) {
-			/*body { -webkit-text-size-adjust: 140% !important; }*/
-			/* Step 1: Reset colors */
-			a[href^="tel"], a[href^="sms"] {
-				text-decoration: none;
-				color: #333; /* or whatever your want */
-				pointer-events: none;
-				cursor: default;
+			body {
+				-webkit-text-size-adjust: 100% !important;
+				-ms-text-size-adjust: 100% !important;
+				font-size: 100% !important;
 			}
-			/* Step 2: Set colors for inteded items */
-			.mobile_link a[href^="tel"], .mobile_link a[href^="sms"] {
-				text-decoration: default;
-				color: #0fa1ca !important;
-				pointer-events: auto;
-				cursor: default;
+			table.tbl-wrap,
+			table.tbl-wrap td.tbl-body {
+				width: auto !important;
+				margin: 0 2em !important;
+			}
+			table.tbl-header td {
+				width: auto !important;
+			}
+			td.tbl-body .mobilehide {
+				display: none !important;
+			}
+			#ticket-number {
+				float: none !important;
+				width: auto !important;
+			}
+			table#ticket-comments>tbody>tr>td {
+				padding: 0 !important;
 			}
 		}
 		@media only screen and (min-device-width: 768px) and (max-device-width: 1024px) {
 			/* tablets, smaller screens, etc */
-			/* Step 1a: Repeating for the iPad */
-			a[href^="tel"], a[href^="sms"] {
-				text-decoration: none;
-				color: #333;
-				pointer-events: none;
-				cursor: default;
-			}
-			.mobile_link a[href^="tel"], .mobile_link a[href^="sms"] {
-				text-decoration: default;
-				color: #0fa1ca !important;
-				pointer-events: auto;
-				cursor: default;
-			}
 		}
 		</style>
 
@@ -168,14 +163,14 @@ if ($this->ticket->submitter('id'))
 					<td bgcolor="#ffffff" align="center" style="border-collapse: collapse;">
 
 						<!-- Start Content Wrapper Table -->
-						<table width="670" cellpadding="0" cellspacing="0" border="0" style="border-collapse: collapse;">
+						<table class="tbl-wrap" width="670" cellpadding="0" cellspacing="0" border="0" style="border-collapse: collapse;">
 							<tbody>
 								<tr style="border-collapse: collapse;">
 									<td bgcolor="#ffffff" width="10" style="border-collapse: collapse;"></td>
-									<td bgcolor="#ffffff" width="650" align="left" style="border-collapse: collapse;">
+									<td class="tbl-body" bgcolor="#ffffff" width="650" align="left" style="border-collapse: collapse;">
 
 										<!-- Start Header Spacer -->
-										<table  width="650" cellpadding="0" cellspacing="0" border="0">
+										<table  width="100%" cellpadding="0" cellspacing="0" border="0">
 											<tr style="border-collapse: collapse;">
 												<td height="30" style="border-collapse: collapse;"></td>
 											</tr>
@@ -183,7 +178,7 @@ if ($this->ticket->submitter('id'))
 										<!-- End Header Spacer -->
 <?php if ($this->delimiter) { ?>
 										<!-- Start Header Spacer -->
-										<table width="650" cellpadding="0" cellspacing="0" border="0" style="border: 1px dashed #b5c6b5;">
+										<table width="100%" cellpadding="0" cellspacing="0" border="0" style="border: 1px dashed #b5c6b5;">
 											<tr style="border-collapse: collapse;">
 												<td height="30" style="border-collapse: collapse; color: #9bac9b;">
 													<div style="height: 0px; overflow: hidden; color: #fff; visibility: hidden;"><?php echo $this->delimiter; ?></div>
@@ -194,7 +189,7 @@ if ($this->ticket->submitter('id'))
 										<!-- End Header Spacer -->
 
 										<!-- Start Header Spacer -->
-										<table  width="650" cellpadding="0" cellspacing="0" border="0">
+										<table  width="100%" cellpadding="0" cellspacing="0" border="0">
 											<tr style="border-collapse: collapse;">
 												<td height="30" style="border-collapse: collapse;"></td>
 											</tr>
@@ -202,13 +197,13 @@ if ($this->ticket->submitter('id'))
 										<!-- End Header Spacer -->
 <?php } ?>
 										<!-- Start Header -->
-										<table cellpadding="2" cellspacing="3" border="0" width="100%" style="border-collapse: collapse; border-bottom: 2px solid #e1e1e1;">
+										<table class="tbl-header" cellpadding="2" cellspacing="3" border="0" width="100%" style="border-collapse: collapse; border-bottom: 2px solid #e1e1e1;">
 											<tbody>
 												<tr>
 													<td width="10%" nowrap="nowrap" align="left" valign="bottom" style="font-size: 1.4em; color: #999; padding: 0 10px 5px 0; text-align: left;">
 														<?php echo $jconfig->getValue('config.sitename'); ?>
 													</td>
-													<td width="80%" align="left" valign="bottom" style="line-height: 1; padding: 0 0 5px 10px;">
+													<td class="mobilehide" width="80%" align="left" valign="bottom" style="line-height: 1; padding: 0 0 5px 10px;">
 														<span style="font-weight: bold; font-size: 0.85em; color: #666; -webkit-text-size-adjust: none;">
 															<a href="<?php echo $juri->base(); ?>" style="color: #666; font-weight: bold; text-decoration: none; border: none;"><?php echo $juri->base(); ?></a>
 														</span>
@@ -224,14 +219,14 @@ if ($this->ticket->submitter('id'))
 										<!-- End Header -->
 
 										<!-- Start Header Spacer -->
-										<table  width="650" cellpadding="0" cellspacing="0" border="0">
+										<table  width="100%" cellpadding="0" cellspacing="0" border="0">
 											<tr style="border-collapse: collapse;">
 												<td height="30" style="border-collapse: collapse;"></td>
 											</tr>
 										</table>
 										<!-- End Header Spacer -->
 
-										<table id="ticket-info" width="650" cellpadding="0" cellspacing="0" border="0" style="border-collapse: collapse; border: 1px solid <?php echo $bdcolor; ?>; background: <?php echo $bgcolor; ?>; font-size: 0.9em; line-height: 1.6em; background-image: -webkit-gradient(linear, 0 0, 100% 100%,
+										<table id="ticket-info" width="100%" cellpadding="0" cellspacing="0" border="0" style="border-collapse: collapse; border: 1px solid <?php echo $bdcolor; ?>; background: <?php echo $bgcolor; ?>; font-size: 0.9em; line-height: 1.6em; background-image: -webkit-gradient(linear, 0 0, 100% 100%,
 																			color-stop(.25, rgba(255, 255, 255, .075)), color-stop(.25, transparent),
 																			color-stop(.5, transparent), color-stop(.5, rgba(255, 255, 255, .075)),
 																			color-stop(.75, rgba(255, 255, 255, .075)), color-stop(.75, transparent),
@@ -254,19 +249,19 @@ if ($this->ticket->submitter('id'))
 																		-webkit-background-size: 30px 30px;
 																		-moz-background-size: 30px 30px;
 																		background-size: 30px 30px;">
-											<thead>
+											<thead class="mobilehide">
 												<tr>
-													<th colspan="2" style="font-weight: normal; border-bottom: 1px solid <?php echo $bdcolor; ?>; padding: 8px; text-align: left" align="left">
+													<th style="font-weight: normal; border-bottom: 1px solid <?php echo $bdcolor; ?>; padding: 8px; text-align: left" align="left">
 														<?php echo JText::_('COM_SUPPORT_NEW_TICKET'); ?>
 													</th>
 												</tr>
 											</thead>
 											<tbody>
 												<tr>
-													<td id="ticket-number" style="padding: 8px; font-size: 2.5em; font-weight: bold; text-align: center; padding: 8px 30px;" align="center">
-														#<?php echo $this->ticket->get('id'); ?>
-													</td>
 													<td width="100%" style="padding: 8px;">
+														<div id="ticket-number" style="float: left; width: 5em; font-size: 2.5em; font-weight: bold; text-align: center; padding: 30px;" align="center">
+															<a href="<?php echo $link; ?>">#<?php echo $this->ticket->get('id'); ?></a>
+														</div>
 														<table style="border-collapse: collapse; font-size: 0.9em;" cellpadding="0" cellspacing="0" border="0">
 															<tbody>
 																<tr>
@@ -305,10 +300,10 @@ if ($this->ticket->submitter('id'))
 																	<th style="text-align: right; padding: 0 0.5em; font-weight: bold; white-space: nowrap; vertical-align: top;" align="right"><?php echo JText::_('COM_SUPPORT_REFERRER'); ?>:</th>
 																	<td style="text-align: left; padding: 0 0.5em;" align="left"><?php echo $this->escape($this->ticket->get('referrer')); ?></td>
 																</tr>
-																<tr>
+																<?php /*<tr>
 																	<th style="text-align: right; padding: 0 0.5em; font-weight: bold; white-space: nowrap; vertical-align: top;" align="right"><?php echo JText::_('COM_SUPPORT_TICKET_DETAILS_LINK'); ?>:</th>
 																	<td style="text-align: left; padding: 0 0.5em;" align="left"><a href="<?php echo $link; ?>"><?php echo $link; ?></a></td>
-																</tr>
+																</tr>*/ ?>
 															</tbody>
 														</table>
 													</td>
@@ -316,7 +311,7 @@ if ($this->ticket->submitter('id'))
 											</tbody>
 										</table>
 
-										<table width="650" id="ticket-comments" style="border-collapse: collapse; margin: 2em 0 0 0; padding: 0" cellpadding="0" cellspacing="0" border="0">
+										<table width="100%" id="ticket-comments" style="border-collapse: collapse; margin: 2em 0 0 0; padding: 0" cellpadding="0" cellspacing="0" border="0">
 											<tbody>
 												<tr>
 													<td style="padding: 0 2em;">
@@ -341,7 +336,7 @@ if ($this->ticket->submitter('id'))
 										</table>
 
 										<!-- Start Footer Spacer -->
-										<table width="650" cellpadding="0" cellspacing="0" border="0">
+										<table width="100%" cellpadding="0" cellspacing="0" border="0">
 											<tr style="border-collapse: collapse;">
 												<td height="30" style="border-collapse: collapse;"></td>
 											</tr>
@@ -349,11 +344,11 @@ if ($this->ticket->submitter('id'))
 										<!-- End Footer Spacer -->
 
 										<!-- Start Header -->
-										<table width="650" cellpadding="2" cellspacing="3" border="0" style="border-collapse: collapse; border-top: 2px solid #e1e1e1;">
+										<table width="100%" cellpadding="2" cellspacing="3" border="0" style="border-collapse: collapse; border-top: 2px solid #e1e1e1;">
 											<tbody>
 												<tr>
 													<td align="left" valign="bottom" style="line-height: 1; padding: 5px 0 0 0; ">
-														<span style="font-size: 0.85em; color: #666; -webkit-text-size-adjust: none;"><?php echo JText::sprintf('COM_SUPPORT_EMAIL_WHY_NOTFIED', $jconfig->getValue('config.sitename'), $link, $link, $base, $base); ?></span>
+														<span style="font-size: 0.85em; color: #666; -webkit-text-size-adjust: none;"><?php echo JText::sprintf('COM_SUPPORT_EMAIL_WHY_NOTFIED', $jconfig->getValue('config.sitename'), $link, '#' . $this->ticket->get('id'), $base, $base); ?></span>
 													</td>
 												</tr>
 											</tbody>
@@ -361,7 +356,7 @@ if ($this->ticket->submitter('id'))
 										<!-- End Header -->
 
 										<!-- Start Footer Spacer -->
-										<table width="650" cellpadding="0" cellspacing="0" border="0">
+										<table width="100%" cellpadding="0" cellspacing="0" border="0">
 											<tbody>
 												<tr style="border-collapse: collapse;">
 													<td height="30" style="border-collapse: collapse; color: #fff !important;"><div style="height: 30px !important; visibility: hidden;">----</div></td>
