@@ -117,7 +117,8 @@ $altdir = ($dir == 'ASC') ? 'DESC' : 'ASC';
 					$xprofile = \Hubzero\User\Profile::getInstance($row->created_by);
 					if (is_object($xprofile))
 					{
-						$name = '<a href="' . JRoute::_('index.php?option=com_members&id=' . $row->created_by) . '">' . $this->escape(stripslashes($xprofile->get('name'))) . '</a>';
+						$name = $this->escape(stripslashes($xprofile->get('name')));
+						$name = ($xprofile->get('public') ? '<a href="' . JRoute::_($xprofile->getLink()) . '">' . $name . '</a>' : $name);
 					}
 			?>
 				<tr>
