@@ -327,6 +327,17 @@ class ItemList implements SeekableIterator, Countable, ArrayAccess
 		return (array_map($callback, $this->_data));
 	}
 
+	/**
+	 * Run a filter over each of the items
+	 *
+	 * @param  Closure  $callback
+	 * @return array
+	 */
+	public function filter(Closure $callback)
+	{
+		return new static(array_filter($this->_data, $callback));
+	}
+
 	/**
 	 * Merge Item Lists
 	 *
@@ -345,4 +356,14 @@ class ItemList implements SeekableIterator, Countable, ArrayAccess
 
 		return new static($this->_data);
 	}
+
+	/**
+	 * Reverse data order.
+	 * 
+	 * @return new \Hubzero\Base\ItemList
+	 */
+	public function reverse()
+	{
+		return new static(array_reverse($this->_data));
+	}
 }
\ No newline at end of file
