@@ -15,17 +15,10 @@ class Migration20141009171309ComTools extends Base
 	 **/
 	public function up()
 	{
-		require_once(JPATH_ROOT . DS . 'components' . DS . 'com_tools' . DS . 'models' . DS . 'mw.utils.php');
-
-		$mwdb = MwUtils::getMWDBO();
-
-		if (!$mwdb->connected())
+		if (!$mwdb = $this->getMWDBO())
 		{
-			$return = new \stdClass();
-			$return->error = new \stdClass();
-			$return->error->type = 'warning';
-			$return->error->message = 'Failed to connect to the middleware database';
-			return $return;
+			$this->setError('Failed to connect to the middleware database', 'warning');
+			return false;
 		}
 
 		if ($mwdb->tableExists('host') && $mwdb->tableHasField('host', 'venue_id'))
@@ -49,4 +42,4 @@ class Migration20141009171309ComTools extends Base
 			$mwdb->query();
 		}
 	}
-}
+}
\ No newline at end of file
