@@ -41,7 +41,7 @@ class plgCronSupport extends JPlugin
 	/**
 	 * Return a list of events
 	 *
-	 * @return     array
+	 * @return  array
 	 */
 	public function onCronEvents()
 	{
@@ -79,10 +79,13 @@ class plgCronSupport extends JPlugin
 	/**
 	 * Close tickets in a pending state for a specific amount of time
 	 *
-	 * @return     boolean
+	 * @param   object   $job  CronModelJob
+	 * @return  boolean
 	 */
-	public function cleanTempUploads($params=null)
+	public function cleanTempUploads(CronModelJob $job)
 	{
+		$params = $job->get('params');
+
 		$sconfig = JComponentHelper::getParams('com_support');
 		$path = JPATH_ROOT . DS . trim($sconfig->get('webpath', '/site/tickets'), DS);
 
@@ -116,13 +119,17 @@ class plgCronSupport extends JPlugin
 	/**
 	 * Close tickets in a pending state for a specific amount of time
 	 *
-	 * @return     boolean
+	 * @param   object   $job  CronModelJob
+	 * @return  boolean
 	 */
-	public function onClosePending($params=null)
+	public function onClosePending(CronModelJob $job)
 	{
+		$params = $job->get('params');
+
 		$database = JFactory::getDBO();
 
-		$sql = "UPDATE `#__support_tickets` AS t SET t.`open`=0, t.`status`=0, t.`closed`=" . $database->quote(JFactory::getDate()->toSql());
+		$slc = "SELECT id, login, email, name FROM `#__support_tickets` AS t";
+		$upd = "UPDATE `#__support_tickets` AS t SET t.`open`=0, t.`status`=0, t.`closed`=" . $database->quote(JFactory::getDate()->toSql());
 
 		$where = array();
 
@@ -132,20 +139,22 @@ class plgCronSupport extends JPlugin
 		if (is_object($params))
 		{
 			$statuses = array();
-			if ($params->get('support_ticketpending_waiting', 1))
+			if (is_numeric($params->get('support_ticketpending_status1')))
 			{
-				$statuses[] = '2';
+				$statuses[] = $params->get('support_ticketpending_status1');
 			}
-			if ($params->get('support_ticketpending_new', 0))
+			if (is_numeric($params->get('support_ticketpending_status2')))
 			{
-				$statuses[] = '0';
+				$statuses[] = $params->get('support_ticketpending_status2');
 			}
-			if ($params->get('support_ticketpending_accepted', 0))
+			if (is_numeric($params->get('support_ticketpending_status3')))
 			{
-				$statuses[] = '1';
+				$statuses[] = $params->get('support_ticketpending_status3');
+			}
+			if (count($statuses))
+			{
+				$where[] = "t.`status` IN (" . implode(',', $statuses) . ")";
 			}
-
-			$where[] = "t.`status` IN (" . implode(',', $statuses) . ")";
 
 			if ($group = $params->get('support_ticketpending_group'))
 			{
@@ -183,11 +192,11 @@ class plgCronSupport extends JPlugin
 			{
 				if ($owned == 1)
 				{
-					$where[] = "(t.`owner` IS NULL OR `owner`='0')";
+					$where[] = "(t.`owner` IS NULL OR `owner`='')";
 				}
 				else if ($owned == 2)
 				{
-					$where[] = "(t.`owner` IS NOT NULL AND `owner` !='0')";
+					$where[] = "(t.`owner` IS NOT NULL AND `owner` !='')";
 				}
 			}
 
@@ -203,7 +212,7 @@ class plgCronSupport extends JPlugin
 				$where[] = "t.`login` IN (" . implode(", ", $usernames) . ")";
 			}
 
-			if ($tags = $params->get('support_ticketpending_excludeTags', 'fixedinstable, fixedinmaster, pendingdevpush, pendingcorepush, pendingupdate'))
+			if ($tags = $params->get('support_ticketpending_excludeTags', ''))
 			{
 				$tags = explode(',', $tags);
 				$tags = array_map('trim', $tags);
@@ -222,7 +231,7 @@ class plgCronSupport extends JPlugin
 						)";
 			}
 
-			if ($tags = $params->get('support_ticketpending_includeTags', 'pendingreview'))
+			if ($tags = $params->get('support_ticketpending_includeTags', ''))
 			{
 				$tags = explode(',', $tags);
 				$tags = array_map('trim', $tags);
@@ -301,15 +310,158 @@ class plgCronSupport extends JPlugin
 
 		if (count($where)  > 0)
 		{
-			$sql .= " WHERE " . implode(" AND ", $where);
+			$slc .= " WHERE " . implode(" AND ", $where);
+			$upd .= " WHERE " . implode(" AND ", $where);
 		}
-		//echo $sql;
-		$database->setQuery($sql);
+
+		$message_id = $params->get('support_ticketpending_message');
+
+		// Get a list of tickets before we update them
+		$tickets = array();
+		if ($message_id)
+		{
+			$database->setQuery($slc);
+			$tickets = $database->loadObjectList();
+		}
+
+		// Update the tickets
+		$database->setQuery($upd);
 		if (!$database->query())
 		{
 			$logger = \JFactory::getLogger();
 			$logger->logError('CRON query failed: ' . $database->getErrorMsg());
 		}
+		// If we're sending a message...
+		else if ($message_id && !empty($tickets))
+		{
+			$lang = JFactory::getLanguage();
+			$lang->load('com_support');
+			$lang->load('com_support', JPATH_BASE);
+
+			include_once(JPATH_ROOT . DS . 'administrator' . DS . 'components' . DS . 'com_support' . DS . 'tables' . DS . 'message.php');
+			include_once(JPATH_ROOT . DS . 'components' . DS . 'com_support' . DS . 'models' . DS . 'ticket.php');
+
+			$message = new SupportMessage($database);
+			$message->load($message_id);
+
+			// Make sure we have a message to send
+			if ($message->message)
+			{
+				$jconfig = JFactory::getConfig();
+
+				$from = array(
+					'name'      => $jconfig->getValue('config.sitename') . ' ' . JText::_('COM_SUPPORT'),
+					'email'     => $jconfig->getValue('config.mailfrom'),
+					'multipart' => md5(date('U'))
+				);
+
+				// Set mail additional args (mail return path - used for bounces)
+				if ($host = JRequest::getVar('HTTP_HOST', '', 'server'))
+				{
+					$args = '-f hubmail-bounces@' . $host;
+				}
+
+				$subject = JText::_('COM_SUPPORT') . ': ' . JText::_('COM_SUPPORT_TICKETS');
+
+				$mailed = array();
+
+				$message->message = str_replace('{sitename}', $jconfig->getValue('config.sitename'), $message->message);
+				$message->message = str_replace('{siteemail}', $jconfig->getValue('config.mailfrom'), $message->message);
+
+				$comment = new SupportModelComment();
+				$comment->set('created', JFactory::getDate()->toSql());
+				$comment->set('created_by', 0);
+				$comment->set('access', 0);
+				$comment->set('comment', $message->message);
+
+				foreach ($tickets as $submitter)
+				{
+					$name  = null;
+					$email = null;
+
+					if ($submitter->login)
+					{
+						// Get the user's account
+						$juser = JUser::getInstance($submitter->login);
+						if (is_object($juser) && $juser->get('id'))
+						{
+							$name  = $juser->get('name');
+							$email = $juser->get('email');
+						}
+					}
+
+					$email = $email ?: $submitter->email;
+					$name  = $name  ?: $submitter->name;
+					$name  = $name  ?: $email;
+
+					if (!$email)
+					{
+						continue;
+					}
+
+					// Try to ensure no duplicates
+					if (in_array($email, $mailed))
+					{
+						continue;
+					}
+
+					$old = new SupportModelTicket($submitter->id);
+					$old->set('open', 1);
+
+					$row = clone $old;
+					$row->set('open', 0);
+
+					$comment->set('comment', str_replace('#XXX', '#' . $row->get('id'), $comment->get('comment')));
+					$comment->set('comment', str_replace('{ticket#}', $row->get('id'), $comment->get('comment')));
+
+					// Compare fields to find out what has changed for this ticket and build a changelog
+					$comment->changelog()->diff($old, $row);
+					$comment->set('ticket', $row->get('id'));
+
+					$eview = new \Hubzero\Component\View(array(
+						'base_path' => JPATH_ROOT . DS . 'components' . DS . 'com_support',
+						'name'      => 'emails',
+						'layout'    => 'comment_plain'
+					));
+					$eview->option     = 'com_support';
+					$eview->controller = 'tickets';
+					$eview->delimiter  = '~!~!~!~!~!~!~!~!~!~!';
+					$eview->boundary   = $from['multipart'];
+					$eview->comment    = $comment;
+					$eview->ticket     = $row;
+
+					$plain = $eview->loadTemplate();
+					$plain = str_replace("\n", "\r\n", $plain);
+
+					// HTML
+					$eview->setLayout('comment_html');
+
+					$html = $eview->loadTemplate();
+					$html = str_replace("\n", "\r\n", $html);
+
+					// Build message
+					$message = new \Hubzero\Mail\Message();
+					$message->setSubject($subject)
+					        ->addFrom($from['email'], $from['name'])
+					        ->addTo($email, $name)
+					        ->addHeader('X-Component', 'com_support')
+					        ->addHeader('X-Component-Object', 'support_ticket_comment');
+
+					$message->addPart($plain, 'text/plain');
+
+					$message->addPart($html, 'text/html');
+
+					// Send mail
+					if (!$message->send())
+					{
+						echo 'CRON email failed: ' . JText::sprintf('Failed to mail %s', $email);
+						//$this->setError(JText::sprintf('Failed to mail %s', $fullEmailAddress));
+						\JFactory::getLogger()->error('CRON email failed: ' . JText::sprintf('Failed to mail %s', $email));
+					}
+					$mailed[] = $email;
+				}
+			}
+		}
 
 		return true;
 	}
@@ -317,10 +469,13 @@ class plgCronSupport extends JPlugin
 	/**
 	 * Send emails reminding people of their open tickets
 	 *
-	 * @return     boolean
+	 * @param   object   $job  CronModelJob
+	 * @return  boolean
 	 */
-	public function sendTicketsReminder($params=null)
+	public function sendTicketsReminder(CronModelJob $job)
 	{
+		$params = $job->get('params');
+
 		$database = JFactory::getDBO();
 		$juri = JURI::getInstance();
 
@@ -341,11 +496,6 @@ class plgCronSupport extends JPlugin
 			if ($group)
 			{
 				$users = $group->get('members');
-				/*$database->setQuery("SELECT username FROM `#__users` WHERE id IN (" . implode(',', $users) . ");");
-				if (!($usernames = $database->loadResultArray()))
-				{
-					$usernames = array();
-				}*/
 			}
 
 			$sql .= " AND owner IN ('" . implode("','", $users) . "') ORDER BY created";
@@ -395,10 +545,11 @@ class plgCronSupport extends JPlugin
 			}*/
 		}
 
-		$from = array();
-		$from['name']      = $jconfig->getValue('config.sitename') . ' ' . JText::_('COM_SUPPORT');
-		$from['email']     = $jconfig->getValue('config.mailfrom');
-		$from['multipart'] = md5(date('U'));
+		$from = array(
+			'name'      => $jconfig->getValue('config.sitename') . ' ' . JText::_('COM_SUPPORT'),
+			'email'     => $jconfig->getValue('config.mailfrom'),
+			'multipart' => md5(date('U'))
+		);
 
 		//set mail additional args (mail return path - used for bounces)
 		if ($host = JRequest::getVar('HTTP_HOST', '', 'server'))
@@ -463,7 +614,6 @@ class plgCronSupport extends JPlugin
 				$this->setError(JText::sprintf('Failed to mail %s', $fullEmailAddress));
 			}
 			$mailed[] = $juser->get('username');
-			//echo $message;
 		}
 
 		return true;
@@ -472,10 +622,13 @@ class plgCronSupport extends JPlugin
 	/**
 	 * Send emails reminding people of their open tickets
 	 *
-	 * @return     boolean
+	 * @param   object   $job  CronModelJob
+	 * @return  boolean
 	 */
-	public function sendTicketList($params=null)
+	public function sendTicketList(CronModelJob $job)
 	{
+		$params = $job->get('params');
+
 		$database = JFactory::getDBO();
 		$juri = JURI::getInstance();
 
@@ -500,20 +653,23 @@ class plgCronSupport extends JPlugin
 			}
 
 			$statuses = array();
-			if ($params->get('support_ticketlist_waiting', 1))
+			if (is_numeric($params->get('support_ticketlist_status1')))
 			{
-				$statuses[] = '2';
+				$statuses[] = $params->get('support_ticketlist_status1');
 			}
-			if ($params->get('support_ticketlist_new', 1))
+			if (is_numeric($params->get('support_ticketlist_status2')))
 			{
-				$statuses[] = '0';
+				$statuses[] = $params->get('support_ticketlist_status2');
 			}
-			if ($params->get('support_ticketlist_accepted', 1))
+			if (is_numeric($params->get('support_ticketlist_status3')))
 			{
-				$statuses[] = '1';
+				$statuses[] = $params->get('support_ticketlist_status3');
 			}
 
-			$where[] = "t.`status` IN (" . implode(',', $statuses) . ")";
+			if (count($statuses))
+			{
+				$where[] = "t.`status` IN (" . implode(',', $statuses) . ")";
+			}
 
 			if ($group = $params->get('support_ticketlist_group'))
 			{
@@ -571,7 +727,7 @@ class plgCronSupport extends JPlugin
 				$where[] = "t.`login` IN (" . implode(", ", $usernames) . ")";
 			}
 
-			if ($tags = $params->get('support_ticketlist_excludeTags', 'fixedinstable, fixedinmaster, pendingdevpush, pendingcorepush, pendingupdate'))
+			if ($tags = $params->get('support_ticketlist_excludeTags'))
 			{
 				$tags = explode(',', $tags);
 				$tags = array_map('trim', $tags);
@@ -734,6 +890,7 @@ class plgCronSupport extends JPlugin
 						$timestamp = JFactory::getDate('-1 year');
 					break;
 
+					case 'all':
 					case '--':
 						$op = '';
 					break;
@@ -755,7 +912,7 @@ class plgCronSupport extends JPlugin
 			$sql .= " WHERE " . implode(" AND ", $where);
 		}
 		$sql .= " ORDER BY t.`created` ASC LIMIT 0, 500";
-		//echo $sql;
+
 		$database->setQuery($sql);
 		if (!($results = $database->loadObjectList()))
 		{
@@ -779,7 +936,7 @@ class plgCronSupport extends JPlugin
 		$from['email']     = $jconfig->getValue('config.mailfrom');
 		$from['multipart'] = md5(date('U'));
 
-		//set mail additional args (mail return path - used for bounces)
+		// Set mail additional args (mail return path - used for bounces)
 		if ($host = JRequest::getVar('HTTP_HOST', '', 'server'))
 		{
 			$args = '-f hubmail-bounces@' . $host;
@@ -859,7 +1016,7 @@ class plgCronSupport extends JPlugin
 
 			$message->addPart($html, 'text/html');
 
-			//set mail
+			// Send mail
 			$logger = \JFactory::getLogger();
 			if (!$message->send())
 			{
@@ -867,7 +1024,6 @@ class plgCronSupport extends JPlugin
 				$logger->error('CRON email failed: ' . JText::sprintf('Failed to mail %s', $email));
 			}
 			$mailed[] = $email;
-			//echo $message;
 		}
 
 		return true;
