@@ -96,9 +96,9 @@ class plgGroupsBlog extends \Hubzero\Plugin\Plugin
 			}
 		}
 
-		include_once(JPATH_ROOT . DS . 'components' . DS . 'com_blog' . DS . 'models' . DS . 'blog.php');
+		include_once(JPATH_ROOT . DS . 'components' . DS . 'com_blog' . DS . 'models' . DS . 'archive.php');
 
-		$this->model = new BlogModel('group', $group->get('gidNumber'));
+		$this->model = new BlogModelArchive('group', $group->get('gidNumber'));
 
 		//are we returning html
 		if ($return == 'html')
@@ -202,7 +202,7 @@ class plgGroupsBlog extends \Hubzero\Plugin\Plugin
 
 		$filters = array(
 			'scope'    => 'group',
-			'group_id' => $group->get('gidNumber'),
+			'scope_id' => $group->get('gidNumber'),
 			'state'    => 'all'
 		);
 
@@ -227,6 +227,82 @@ class plgGroupsBlog extends \Hubzero\Plugin\Plugin
 		return $arr;
 	}
 
+	/**
+	 * Remove any associated data when group is deleted
+	 *
+	 * @param   object  $group  Group being deleted
+	 * @return  string  Log of items removed
+	 */
+	public function onGroupDelete($group)
+	{
+		// Import needed libraries
+		include_once(JPATH_ROOT . DS . 'components' . DS . 'com_blog' . DS . 'models' . DS . 'archive.php');
+
+		$database = JFactory::getDBO();
+
+		$tbl = new BlogTableEntry($database);
+
+		// Get all the IDs for entries associated with this group
+		$entries = $tbl->find(
+			'list',
+			array(
+				'scope' => 'group',
+				'scope_id' => $group->get('gidNumber')
+			),
+			array('m.id')
+		);
+
+		// Start the log text
+		$log = JText::_('PLG_GROUPS_BLOG_LOG') . ': ';
+
+		if (count($entries) > 0)
+		{
+			// Loop through all the IDs for pages associated with this group
+			foreach ($entries as $entry)
+			{
+				$tbl->id = $entry->id;
+				$tbl->state = '-1';
+				$tbl->store();
+
+				// Add the ID to the log
+				$log .= $entry->id . ' ' . "\n";
+			}
+		}
+		else
+		{
+			$log .= JText::_('PLG_GROUPS_BLOG_NO_RESULTS_FOUND') . "\n";
+		}
+
+		// Return the log
+		return $log;
+	}
+
+	/**
+	 * Return a count of items that will be removed when group is deleted
+	 *
+	 * @param   object  $group  Group to delete
+	 * @return  string
+	 */
+	public function onGroupDeleteCount($group)
+	{
+		include_once(JPATH_ROOT . DS . 'components' . DS . 'com_blog' . DS . 'models' . DS . 'archive.php');
+
+		$database = JFactory::getDBO();
+
+		$tbl = new BlogTableEntry($database);
+
+		// Get all the IDs for entries associated with this group
+		$entries = $tbl->find(
+			'count',
+			array(
+				'scope' => 'group',
+				'scope_id' => $group->get('gidNumber')
+			)
+		);
+
+		return JText::_('PLG_GROUPS_BLOG_LOG') . ': ' . $entries;
+	}
+
 	/**
 	 * Parse an SEF URL into its component bits
 	 * stripping out the path leading up to the blog plugin
@@ -317,7 +393,7 @@ class plgGroupsBlog extends \Hubzero\Plugin\Plugin
 			'year'       => JRequest::getInt('year', 0),
 			'month'      => JRequest::getInt('month', 0),
 			'scope'      => 'group',
-			'group_id'   => $this->group->get('gidNumber'),
+			'scope_id'   => $this->group->get('gidNumber'),
 			'search'     => JRequest::getVar('search',''),
 			'authorized' => false,
 			'state'      => 'public'
@@ -419,7 +495,7 @@ class plgGroupsBlog extends \Hubzero\Plugin\Plugin
 			'year'       => JRequest::getInt('year', 0),
 			'month'      => JRequest::getInt('month', 0),
 			'scope'      => 'group',
-			'group_id'   => $this->group->get('gidNumber'),
+			'scope_id'   => $this->group->get('gidNumber'),
 			'search'     => JRequest::getVar('search',''),
 			'created_by' => JRequest::getInt('author', 0),
 			'state'      => 'public'
@@ -560,7 +636,7 @@ class plgGroupsBlog extends \Hubzero\Plugin\Plugin
 		}
 
 		// make sure the group owns this
-		if ($view->row->get('group_id') != $this->group->get('gidNumber'))
+		if ($view->row->get('scope_id') != $this->group->get('gidNumber'))
 		{
 			JError::raiseError(403, JText::_('PLG_GROUPS_BLOG_NOT_AUTH'));
 			return;
@@ -571,7 +647,7 @@ class plgGroupsBlog extends \Hubzero\Plugin\Plugin
 			'limit'      => 10,
 			'start'      => 0,
 			'scope'      => 'group',
-			'group_id'   => $this->group->get('gidNumber'),
+			'scope_id'   => $this->group->get('gidNumber'),
 			'created_by' => 0
 		);
 
@@ -666,7 +742,7 @@ class plgGroupsBlog extends \Hubzero\Plugin\Plugin
 			$view->entry->set('allow_comments', 1);
 			$view->entry->set('state', 1);
 			$view->entry->set('scope', 'group');
-			$view->entry->set('group_id', $this->group->get('gidNumber'));
+			$view->entry->set('scope_id', $this->group->get('gidNumber'));
 		}
 
 		if ($this->getError())
