@@ -31,24 +31,13 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die( 'Restricted access' );
 
-$dateFormat = '%d %b, %Y';
-$tz = null;
-
-if (version_compare(JVERSION, '1.6', 'ge'))
-{
-	$dateFormat = 'd M, Y';
-	$tz = false;
-}
-
 if ($this->results) {
-	ximport('Hubzero_View_Helper_Html');
-
 	include_once( JPATH_ROOT.DS.'administrator'.DS.'components'.DS.'com_resources'.DS.'tables'.DS.'review.php' );
 
 	plgGroupsResources::documents();
 
-	$database =& JFactory::getDBO();
-	$juser =& JFactory::getUser();
+	$database = JFactory::getDBO();
+	$juser = JFactory::getUser();
 ?>
 	<table class="related-resources" summary="<?php echo JText::_('PLG_GROUPS_RESOURCES_DASHBOARD_SUMMARY'); ?>">
 		<tbody>
@@ -98,7 +87,7 @@ if ($this->results) {
 		}
 
 		// Encode some potentially troublesome characters
-		$line->title = Hubzero_View_Helper_Html::xhtml( $line->title );
+		$line->title = $this->escape( $line->title );
 
 		// Make sure we have an SEF, otherwise it's a querystring
 		if (strstr($line->href,'option=')) {
@@ -139,7 +128,7 @@ if ($this->results) {
 <?php } ?>
 									<tr>
 										<th><?php echo JText::_('PLG_GROUPS_RESOURCES_DATE'); ?></th>
-										<td><?php echo JHTML::_('date',$line->publish_up, $dateFormat, $tz); ?></td>
+										<td><?php echo JHTML::_('date',$line->publish_up, JText::_('DATE_FORMAT_HZ1')); ?></td>
 									</tr>
 									<tr>
 										<th><?php echo JText::_('PLG_GROUPS_RESOURCES_AVG_RATING'); ?></th>
@@ -160,7 +149,7 @@ if ($this->results) {
 								</tbody>
 							</table>
 						</div>
-						<?php echo Hubzero_View_Helper_Html::shortenText( $line->itext ); ?>
+						<?php echo \Hubzero\Utility\String::truncate($line->itext, 300); ?>
 					</div>
 				</td>
 				<td class="type"><?php echo $line->area; ?></td>
