@@ -31,147 +31,140 @@ if (!jq) {
 }
 
 HUB.ProjectMicroblog = {
-	
+
 	jQuery: jq,
-	
-	initialize: function() 
-	{			
+
+	initialize: function()
+	{
 		var $ = this.jQuery;
-				
+
 		// Showing comment area
-		$('.showc').each(function(i, item) 
+		$('.showc').each(function(i, item)
 		{
-			$(item).on('click', function(e) 
+			$(item).on('click', function(e)
 			{
 				e.preventDefault();
 				var id = $(item).attr('id').replace('addc_', '');
-				var acid = '#commentform_' + id;				
-			
-				if ($(acid) && $(acid).hasClass('hidden')) 
+				var acid = '#commentform_' + id;
+				var scrollTo = $(acid).offset().top - 100;
+
+				if ($(acid) && $(acid).hasClass('hidden'))
 				{
 					$(acid).removeClass('hidden');
-					var coord = $(acid).position();
+
 					$('html, body').animate({
-						scrollTop: $(acid).offset().top
-					}, 2000);
-				} 
-				else if ($(acid) && !$(acid).hasClass('hidden')) 
-				{
-					$(acid).addClass('hidden');
+						scrollTop: scrollTo
+					}, 1000);
+					var txt = $(acid).find('.commentarea')[0];
+					HUB.ProjectMicroblog.focusTextArea(txt);
 				}
-			});	
+				else if ($(acid) && !$(acid).hasClass('hidden'))
+				{
+					$('html, body').animate({
+						scrollTop: scrollTo
+					}, 1000);
+				}
+				$(txt).focus();
+			});
 		});
-		
+
 		// Show more
 		$('.more-content').each(function(i, el)
 		{
-			$(el).on('click', function(e) 
+			$(el).on('click', function(e)
 			{
 				e.preventDefault();
 				var shortBody = $(el).parent().parent().find("span.body");
 				var longBody  = $(el).parent().parent().find("span.fullbody");
-								
+
 				$(shortBody).addClass('hidden');
 				$(longBody).removeClass('hidden');
 			});
 		});
-		
+
 		// Comment form
-		$('.commentarea').each(function(i, item) 
+		$('.commentarea').each(function(i, item)
 		{
 			// Submit comments on enter
 			$(item).bind("enterKey",function(e)
-			{   
+			{
 				var form = $(item).parent().parent().parent().parent().find("form");
-				
+
 				// Submit if not empty
 				if ($(item).val() != '')
 				{
 					$(form).submit();
 				}
 			});
-			
-			$(item).on('keypress', function(e) 
+
+			$(item).on('keypress', function(e)
 			{
 				if (e.keyCode == 13)
 			    {
-			        e.preventDefault(); 
+			        e.preventDefault();
 			    }
 			});
-			
-			$(item).on('keyup', function(e) 
-			{				
+
+			$(item).on('keyup', function(e)
+			{
 				if (e.keyCode == 13)
 			    {
 			        $(this).trigger("enterKey");
 			    }
 			});
-			
-			if ($(item).val() == '') 
+
+			if ($(item).val() == '')
 			{
-				$(item)
-					.css('color', '#999')
-					.css('height', '20px')
-					.css('font-size', '100%');
+				HUB.ProjectMicroblog.unfocusTextArea(this);
 			}
-			$(item).on('focus', function(e) 
+			$(item).on('focus', function(e)
 			{
-				$(this).css('color', '#000')
-					   .css('height', '50px');
+				HUB.ProjectMicroblog.focusTextArea(this);
 			});
 		});
-		
+
 		// Blog entry form
-		if ($('#blogentry')) 
+		if ($('#blogentry'))
 		{
-			if ($('#blogentry').val() == '') 
+			if ($('#blogentry').val() == '')
 			{
-				$('#blogentry')
-					.css('color', '#999')
-					.css('height', '20px')
-					.css('font-size', '100%');
+				HUB.ProjectMicroblog.unfocusTextArea($('#blogentry'));
 				$('#blog-submit').addClass('hidden');
 				$('#blog-submitarea').css('height', '0');
 			}
-			
-			$('#blogentry').on('focus', function(e) 
+
+			$('#blogentry').on('focus', function(e)
 			{
-				$('#blogentry')
-					.css('color', '#000')
-					.css('height', '60px');
+				HUB.ProjectMicroblog.focusTextArea($('#blogentry'));
 				$('#blog-submit').removeClass('hidden');
 				$('#blog-submitarea').css('height', '20px');
-			});	
-			
+			});
+
 			// On click outside
 			if ($('#blog-submitarea')) {
 				$('#blog-submitarea').on('click', function(e) {
-
-						$('#blogentry')
-							.css('color', '#999')
-							.css('height', '20px');
+						HUB.ProjectMicroblog.unfocusTextArea($('#blogentry'));
 						$('#blog-submit').addClass('hidden');
 						$('#blog-submitarea').css('height', '0');
-				});	
+				});
 			}
 		}
-		
+
 		// Do not allow to post empty values
 		if ($('#blog-submit')) {
 			$('#blog-submit').on('click', function(e){
 				if ($('#blogentry').val() == '') {
 					e.preventDefault();
-					$('#blogentry')
-						.css('color', '#999')
-						.css('height', '20px');
+					HUB.ProjectMicroblog.unfocusTextArea($('#blogentry'));
 					$('#blog-submit').addClass('hidden');
 					$('#blog-submitarea').css('height', '0');
 				}
-			});	
+			});
 		}
 		$('.c-submit').each(function(index, item) {
+			$(item).addClass('hidden');
 			$(item).on('click', function(e){
-				
+
 				var cid = $(this).attr('id').replace('cs_', '');
 				var caid = '#ca_' + cid;
 				var acid = '#commentform_' + cid;
@@ -187,7 +180,7 @@ HUB.ProjectMicroblog = {
 		// Confirm delete
 		$('.delit').each(function(i, el) {
 			var link = $(el).find("a");
-			$(link).on('click', function(e) {	
+			$(link).on('click', function(e) {
 				e.preventDefault();
 				if (HUB.Projects) {
 					HUB.Projects.addConfirm($(link), 'Permanently delete this entry?', 'yes, delete', 'cancel');
@@ -197,14 +190,14 @@ HUB.ProjectMicroblog = {
 				}
 			});
 		});
-		
+
 		// Show more updates
 		if ($('#more-updates') && $('#pid')) {
 			$('#more-updates').on('click', function(e) {
 				e.preventDefault();
 
 				var link = $('#more-updates').find("a");
-				
+
 				if (link.length)
 				{
 					var url = link.attr('href') + '&no_html=1&ajax=1&action=update';
@@ -213,9 +206,27 @@ HUB.ProjectMicroblog = {
 						$('#latest_activity').html(data);
 						HUB.ProjectMicroblog.initialize();
 					});
-				}				
-			});	
+				}
+			});
 		}
+	},
+
+	focusTextArea: function(item)
+	{
+		var $ = this.jQuery;
+
+		$(item).css('color', '#000')
+			   .css('height', '100px')
+			   .css('border', '2px solid #6bb7d6');
+	},
+
+	unfocusTextArea: function(item)
+	{
+		var $ = this.jQuery;
+
+		$(item).css('color', '#999')
+			   .css('height', '35px')
+			   .css('border', '1px solid #CCC');
 	}
 }
 
