@@ -29,52 +29,40 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
-jimport('joomla.plugin.plugin');
-	
 /**
  * Resources Plugin class for usage
  */
-class plgResourcesUsage extends JPlugin
+class plgResourcesUsage extends \Hubzero\Plugin\Plugin
 {
 	/**
-	 * Constructor
-	 * 
-	 * @param      object &$subject Event observer
-	 * @param      array  $config   Optional config values
-	 * @return     void
+	 * Affects constructor behavior. If true, language files will be loaded automatically.
+	 *
+	 * @var    boolean
 	 */
-	public function __construct(&$subject, $config)
-	{
-		parent::__construct($subject, $config);
-
-		$this->loadLanguage();
-	}
+	protected $_autoloadLanguage = true;
 
 	/**
 	 * Return the alias and name for this category of content
-	 * 
+	 *
 	 * @param      object $resource Current resource
 	 * @return     array
 	 */
-	public function &onResourcesAreas($model) 
+	public function &onResourcesAreas($model)
 	{
-		if ($model->type->params->get('plg_' . $this->_name) && $model->isTool()) 
+		$areas = array();
+
+		if ($model->type->params->get('plg_' . $this->_name) && $model->isTool())
 		{
 			// Only show tab for tools
-			$areas = array(
-				'usage' => JText::_('PLG_RESOURCES_USAGE')
-			);
-		} 
-		else 
-		{
-			$areas = array();
+			$areas['usage'] = JText::_('PLG_RESOURCES_USAGE');
 		}
+
 		return $areas;
 	}
 
 	/**
 	 * Return data on a resource view (this will be some form of HTML)
-	 * 
+	 *
 	 * @param      object  $resource Current resource
 	 * @param      string  $option    Name of the component
 	 * @param      array   $areas     Active area(s)
@@ -90,21 +78,21 @@ class plgResourcesUsage extends JPlugin
 		);
 
 		// Check if our area is in the array of areas we want to return results for
-		if (is_array($areas)) 
+		if (is_array($areas))
 		{
-			if (!array_intersect($areas, $this->onResourcesAreas($model)) 
-			 && !array_intersect($areas, array_keys($this->onResourcesAreas($model)))) 
+			if (!array_intersect($areas, $this->onResourcesAreas($model))
+			 && !array_intersect($areas, array_keys($this->onResourcesAreas($model))))
 			{
 				$rtrn = 'metadata';
 			}
 		}
-		if (!$model->type->params->get('plg_usage')) 
+		if (!$model->type->params->get('plg_usage'))
 		{
 			return $arr;
 		}
 
 		// Display only for tools
-		if (!$model->isTool()) 
+		if (!$model->isTool())
 		{
 			//return $arr;
 			$rtrn == 'metadata';
@@ -116,16 +104,9 @@ class plgResourcesUsage extends JPlugin
 		$tables = $database->getTableList();
 		$table  = $database->getPrefix() . 'resource_stats_tools';
 
-		if ($model->resource->alias) 
-		{
-			$url = JRoute::_('index.php?option=' . $option . '&alias=' . $model->resource->alias . '&active=usage');
-		} 
-		else 
-		{
-			$url = JRoute::_('index.php?option=' . $option . '&id=' . $model->resource->id . '&active=usage');
-		}
+		$url = JRoute::_('index.php?option=' . $option . '&' . ($model->resource->alias ? 'alias=' . $model->resource->alias : 'id=' . $model->resource->id) . '&active=' . $this->_name);
 
-		if (!in_array($table, $tables)) 
+		if (!in_array($table, $tables))
 		{
 			$arr['html'] = '<p class="error">'. JText::_('PLG_RESOURCES_USAGE_MISSING_TABLE') . '</p>';
 			$arr['metadata'] = '<p class="usage"><a href="' . $url . '">' . JText::_('PLG_RESOURCES_USAGE_DETAILED') . '</a></p>';
@@ -137,21 +118,21 @@ class plgResourcesUsage extends JPlugin
 		$period = JRequest::getInt('period', $this->params->get('period', 14));
 
 		include_once(JPATH_ROOT . DS . 'administrator' . DS . 'components' . DS . $option . DS . 'tables' . DS . 'stats.php');
-		if ($model->isTool()) 
+		if ($model->isTool())
 		{
 			$stats = new ResourcesStatsTools($database);
-		} 
-		else 
+		}
+		else
 		{
 			$stats = new ResourcesStats($database);
 		}
-		$stats->loadStats($model->resource->id, $period, $dthis);
+		$stats->loadStats($model->resource->id, $period); //, $dthis);
 
 		$clusters = new ResourcesStatsClusters($database);
 		$clusters->loadStats($model->resource->id);
 
 		// Are we returning HTML?
-		if ($rtrn == 'all' || $rtrn == 'html') 
+		if ($rtrn == 'all' || $rtrn == 'html')
 		{
 			$action = JRequest::getVar('action', '');
 			if ($action == 'top')
@@ -164,13 +145,12 @@ class plgResourcesUsage extends JPlugin
 				$this->getValues($model->resource->id, JRequest::getInt('period', 13));
 				return;
 			}
-			\Hubzero\Document\Assets::addComponentStylesheet('com_usage');
 
 			// Instantiate a view
 			$view = new \Hubzero\Plugin\View(
 				array(
-					'folder'  => 'resources',
-					'element' => 'usage',
+					'folder'  => $this->_type,
+					'element' => $this->_name,
 					'name'    => 'browse'
 				)
 			);
@@ -184,7 +164,7 @@ class plgResourcesUsage extends JPlugin
 			$view->dthis      = $dthis;
 			$view->period     = $period;
 			$view->params     = $this->params;
-			if ($this->getError()) 
+			if ($this->getError())
 			{
 				$view->setError($this->getError());
 			}
@@ -193,23 +173,23 @@ class plgResourcesUsage extends JPlugin
 			$arr['html'] = $view->loadTemplate();
 		}
 
-		if ($rtrn == 'all' || $rtrn == 'metadata') 
+		if ($rtrn == 'all' || $rtrn == 'metadata')
 		{
 			if (!$stats->users)
 			{
 				$stats->users = 0;
 			}
-			if ($model->isTool()) 
+			if ($model->isTool())
 			{
-				$arr['metadata'] = '<p class="usage"><a href="' . $url . '">' . JText::sprintf('PLG_RESOURCES_USAGE_NUM_USERS', $stats->users) . '</a></p>';
-			} 
-			else 
-			{
-				$arr['metadata'] = '<p class="usage">' . JText::sprintf('%s users', $stats->users) . '</p>';
+				$arr['metadata'] = '<p class="usage"><a href="' . $url . '">' . JText::sprintf('PLG_RESOURCES_USAGE_NUM_USERS_DETAILED', $stats->users) . '</a></p>';
 			}
-			if ($clusters->users && $clusters->classes) 
+			else
 			{
-				$arr['metadata'] .= '<p class="usage">' . JText::sprintf('%s users', $clusters->users) . ' in ' . JText::sprintf('%s classes', $clusters->classes) . '</p>';
+				$arr['metadata'] = '<p class="usage">' . JText::sprintf('PLG_RESOURCES_USAGE_NUM_USERS', $stats->users) . '</p>';
+			}
+			if ($clusters->users && $clusters->classes)
+			{
+				$arr['metadata'] .= '<p class="usage">' . JText::sprintf('PLG_RESOURCES_USAGE_NUM_USERS_IN_CLASSES', $clusters->users, $clusters->classes) . '</p>';
 			}
 		}
 
@@ -218,27 +198,27 @@ class plgResourcesUsage extends JPlugin
 
 	/**
 	 * Round time into nearest second/minutes/hours/days
-	 * 
+	 *
 	 * @param      integer $time Time
 	 * @return     string
 	 */
-	public static function timeUnits($time) 
+	public static function timeUnits($time)
 	{
-		if ($time < 60) 
+		if ($time < 60)
 		{
-			$data = round($time, 2) . ' ' . JText::_('PLG_RESOURCES_USAGE_SECONDS');
-		} 
-		else if ($time > 60 && $time < 3600) 
+			$data = JText::sprintf('PLG_RESOURCES_USAGE_SECONDS', round($time, 2));
+		}
+		else if ($time > 60 && $time < 3600)
 		{
-			$data = round(($time/60), 2) . ' ' . JText::_('PLG_RESOURCES_USAGE_MINUTES');
-		} 
-		else if ($time >= 3600 && $time < 86400) 
+			$data = JText::sprintf('PLG_RESOURCES_USAGE_MINUTES', round(($time/60), 2));
+		}
+		else if ($time >= 3600 && $time < 86400)
 		{
-			$data = round(($time/3600), 2) . ' ' . JText::_('PLG_RESOURCES_USAGE_HOURS');
-		} 
-		else if ($time >= 86400) 
+			$data = JText::sprintf('PLG_RESOURCES_USAGE_HOURS', round(($time/3600), 2));
+		}
+		else if ($time >= 86400)
 		{
-			$data = round(($time/86400), 2) . ' ' . JText::_('PLG_RESOURCES_USAGE_DAYS');
+			$data = JText::sprintf('PLG_RESOURCES_USAGE_DAYS', round(($time/86400), 2));
 		}
 
 		return $data;
@@ -246,7 +226,7 @@ class plgResourcesUsage extends JPlugin
 
 	/**
 	 * Get overview data
-	 * 
+	 *
 	 * @param      integer $id  Resource ID
 	 * @return     array
 	 */
@@ -254,9 +234,9 @@ class plgResourcesUsage extends JPlugin
 	{
 		$database = JFactory::getDBO();
 
-		$sql = "SELECT * 
-				FROM #__resource_stats_tools 
-				WHERE resid = '$id' 
+		$sql = "SELECT *
+				FROM `#__resource_stats_tools`
+				WHERE resid = '$id'
 				AND period = '$period'
 				ORDER BY `datetime` ASC";
 		$database->setQuery($sql);
@@ -265,7 +245,7 @@ class plgResourcesUsage extends JPlugin
 
 	/**
 	 * Check for data for a given time period
-	 * 
+	 *
 	 * @param      integer $id  Resource ID
 	 * @param      integer $top Value type (1 = country, 2 = domain, 3 = org)
 	 * @param      integer $tid Stats ID for that tool
@@ -281,10 +261,10 @@ class plgResourcesUsage extends JPlugin
 			return array();
 		}
 
-		$sql = "SELECT v.*, t.datetime, t.`processed_on` 
-				FROM #__resource_stats_tools AS t
-				LEFT JOIN #__resource_stats_tools_topvals AS v ON v.id=t.id
-				WHERE t.resid = '$id' 
+		$sql = "SELECT v.*, t.datetime, t.`processed_on`
+				FROM `#__resource_stats_tools` AS t
+				LEFT JOIN `#__resource_stats_tools_topvals` AS v ON v.id=t.id
+				WHERE t.resid = '$id'
 				AND t.period = '$prd'
 				AND t.datetime = '" . $datetime . "-00 00:00:00'
 				AND t.id = $tid
@@ -298,7 +278,7 @@ class plgResourcesUsage extends JPlugin
 	/**
 	 * Get the stats ID for a specific resource
 	 * Getting this now allows for faster data pulling later on
-	 * 
+	 *
 	 * @param      integer $id       Resource ID
 	 * @param      string  $datetime Timestamp YYYY-MM-DD
 	 * @return     array
@@ -307,7 +287,7 @@ class plgResourcesUsage extends JPlugin
 	{
 		$database = JFactory::getDBO();
 
-		$sql = "SELECT t.id FROM #__resource_stats_tools AS t WHERE t.resid = '$id' AND t.period = '" . $period . "' AND t.datetime = '" . $datetime . "-00 00:00:00' ORDER BY t.id LIMIT 1";
+		$sql = "SELECT t.id FROM `#__resource_stats_tools` AS t WHERE t.resid = " . $database->quote($id) . " AND t.period = " . $database->quote($period) . " AND t.datetime = '" . $datetime . "-00 00:00:00' ORDER BY t.id LIMIT 1";
 		$database->setQuery($sql);
 		return $database->loadResult();
 	}
@@ -315,7 +295,7 @@ class plgResourcesUsage extends JPlugin
 	/**
 	 * Get data for orgs, countries, domains for a given time period
 	 * (1 = country, 2 = domain, 3 = org)
-	 * 
+	 *
 	 * @param      integer $id       Resource ID
 	 * @param      string  $datetime Timestamp YYYY-MM-DD
 	 * @return     array
@@ -323,23 +303,23 @@ class plgResourcesUsage extends JPlugin
 	public function getValues($id, $period)
 	{
 		$results = $this->getOverview($id, $period);
-		
+
 		$users = array();
 		//$interactive = array();
 		//$sessions = array();
 		$runs = array();
-		
+
 		$data = new stdClass;
 		$data->points = array();
 		//$data->runs = array();
-		
+
 		foreach ($results as $result)
 		{
 			//$point = new stdClass;
 			$result->datetime = str_replace('-', '/', str_replace('-00 00:00:00', '-01', $result->datetime)) . ' 00:00:00';
 			//$point->users = $result->users;
 			//$point->users = $result->users;
-	
+
 			//$data->users[]       = "[Date.parse('" . str_replace('-', '/', str_replace('-00 00:00:00', '-01', $result->datetime)) . " 00:00:00')," . $result->users . "]";
 			//$interactive[] = "[Date.parse('" . str_replace('-', '/', str_replace('-00 00:00:00', '-01', $result->datetime)) . " 00:00:00')," . $result->sessions . "]";
 			//$sessions[]    = "[Date.parse('" . str_replace('-', '/', str_replace('-00 00:00:00', '-01', $result->datetime)) . " 00:00:00')," . $result->simulations . "]";
@@ -349,12 +329,7 @@ class plgResourcesUsage extends JPlugin
 			//$usersTop = ($result->users > $usersTop) ? $result->users : $usersTop;
 			//$runsTop = ($result->jobs > $runsTop) ? $result->jobs : $runsTop;
 		}
-		
-		/*$data = 'data = {
-			users: [' . implode(',', $users) . '],
-			runs: [' . implode(',', $runs) . ']
-		}';*/
-		
+
 		ob_clean();
 
 		echo json_encode($data);
@@ -364,7 +339,7 @@ class plgResourcesUsage extends JPlugin
 	/**
 	 * Get data for orgs, countries, domains for a given time period
 	 * (1 = country, 2 = domain, 3 = org)
-	 * 
+	 *
 	 * @param      integer $id       Resource ID
 	 * @param      string  $datetime Timestamp YYYY-MM-DD
 	 * @return     array
@@ -410,7 +385,7 @@ class plgResourcesUsage extends JPlugin
 			foreach ($orgs as $row)
 			{
 				$ky = str_replace('-', '/', str_replace('-00 00:00:00', '-01', $row->datetime));
-				if ($row->datetime && preg_match("/([0-9]{4})-([0-9]{2})-([0-9]{2})[ ]([0-9]{2}):([0-9]{2}):([0-9]{2})/", $row->datetime, $regs)) 
+				if ($row->datetime && preg_match("/([0-9]{4})-([0-9]{2})-([0-9]{2})[ ]([0-9]{2}):([0-9]{2}):([0-9]{2})/", $row->datetime, $regs))
 				{
 					$ky = $regs[1] . '/' . $regs[2] . '/01'; //mktime($regs[4], $regs[5], $regs[6], , $regs[3], );
 				}
@@ -453,11 +428,11 @@ class plgResourcesUsage extends JPlugin
 			foreach ($countries as $row)
 			{
 				$ky = str_replace('-', '/', str_replace('-00 00:00:00', '-01', $row->datetime));
-				if ($row->datetime && preg_match("/([0-9]{4})-([0-9]{2})-([0-9]{2})[ ]([0-9]{2}):([0-9]{2}):([0-9]{2})/", $row->datetime, $regs)) 
+				if ($row->datetime && preg_match("/([0-9]{4})-([0-9]{2})-([0-9]{2})[ ]([0-9]{2}):([0-9]{2}):([0-9]{2})/", $row->datetime, $regs))
 				{
 					$ky = $regs[1] . '/' . $regs[2] . '/01'; //mktime($regs[4], $regs[5], $regs[6], , $regs[3], );
 				}
-	
+
 				if (!isset($r[$ky]))
 				{
 					$i = 0;
@@ -489,7 +464,7 @@ class plgResourcesUsage extends JPlugin
 			foreach ($domains as $row)
 			{
 				$ky = str_replace('-', '/', str_replace('-00 00:00:00', '-01', $row->datetime));
-				if ($row->datetime && preg_match("/([0-9]{4})-([0-9]{2})-([0-9]{2})[ ]([0-9]{2}):([0-9]{2}):([0-9]{2})/", $row->datetime, $regs)) 
+				if ($row->datetime && preg_match("/([0-9]{4})-([0-9]{2})-([0-9]{2})[ ]([0-9]{2}):([0-9]{2}):([0-9]{2})/", $row->datetime, $regs))
 				{
 					$ky = $regs[1] . '/' . $regs[2] . '/01'; //mktime($regs[4], $regs[5], $regs[6], , $regs[3], );
 				}
