@@ -65,16 +65,19 @@ class FileMacro extends WikiMacro
 				<li><code>right</code>, <code>left</code>, <code>top</code> or <code>bottom</code> are interpreted as the alignment for the file (currently, only applies to images)</li>
 				<li><code>link=some Link...</code> replaces the link to the file source by the one specified using <code>link</code>. If no value is specified, the link is simply removed.</li>
 				<li><code>nolink</code> means without link to image source (deprecated, use <code>link=</code>)</li>
-				<li><code>key=value</code> style are interpreted as HTML attributes or CSS style indications for the file. Valid keys are:</li>
-				<li>align, border, width, height, alt, desc, title, longdesc, class, id and usemap</li>
+				<li><code>key=value</code> style are interpreted as HTML attributes or CSS style indications for the file. Valid keys are:<br />
+				align, border, width, height, alt, desc, title, longdesc, class, id and usemap</li>
 				<li><code>border</code> can only be a number</li>
 				<li><code>altimage</code> is only valid for CDF files. It is ignored for other file types.</li>
+				<li><code>details</code> indicates wether to display file information (size, etc.). Defaults to: on, Accepts: false, no, off, hide, hidden, none.<br />
+				The single attribute <code>nodetails</code> is an alternative.</li>
 			</ul>
 			<p>Examples:</p>
 			<ul>
 				<li><code>[[File(mydoc.pdf)]]</code> # simplest</li>
 				<li><code>[[File(mydoc.pdf, alt="My document")]]</code> # ALT text. For images, this is the "alt" attribute. For files, the "title" attribute.</li>
 				<li><code>[[File(mydoc.pdf, desc="My document")]]</code> # Link text. If none is provided, the filename will be used.</li>
+				<li><code>[[File(mydoc.pdf, details="off")]]</code> or <code>[[File(mydoc.pdf, nodetails)]]</code> to link a file and NOT display file metadata.</li>
 			</ul>
 			<p>Examples (CDF):</p>
 			<ul>
@@ -108,16 +111,17 @@ class FileMacro extends WikiMacro
 		$this->attr   = array();
 		$this->attr['href']  = '';
 		$this->attr['style'] = array();
+		$this->attr['details'] = true;
 
 		// Get single attributes
 		// EX: [[Image(myimage.png, nolink, right)]]
-		$argues = preg_replace_callback('/[, ](left|right|top|center|bottom|[0-9]+(px|%|em)?)(?:[, ]|$)/i', array(&$this, 'parseSingleAttribute'), $content);
+		$argues = preg_replace_callback('/[, ](left|right|top|center|bottom|nodetails|[0-9]+(px|%|em)?)(?:[, ]|$)/i', array(&$this, 'parseSingleAttribute'), $content);
 		// Get quoted attribute/value pairs
 		// EX: [[Image(myimage.png, desc="My description, contains, commas")]]
-		$argues = preg_replace_callback('/[, ](alt|altimage|althref|desc|title|width|height|align|border|longdesc|class|id|usemap|link|rel)=(?:["\'])([^"\']*)(?:["\'])/i', array(&$this, 'parseAttributeValuePair'), $content);
+		$argues = preg_replace_callback('/[, ](alt|altimage|althref|desc|title|width|height|align|border|longdesc|class|id|usemap|link|rel|details)=(?:["\'])([^"\']*)(?:["\'])/i', array(&$this, 'parseAttributeValuePair'), $content);
 		// Get non-quoted attribute/value pairs
 		// EX: [[Image(myimage.png, width=100)]]
-		$argues = preg_replace_callback('/[, ](alt|altimage|althref|desc|title|width|height|align|border|longdesc|class|id|usemap|link|rel)=([^"\',]*)(?:[, ]|$)/i', array(&$this, 'parseAttributeValuePair'), $content);
+		$argues = preg_replace_callback('/[, ](alt|altimage|althref|desc|title|width|height|align|border|longdesc|class|id|usemap|link|rel|details)=([^"\',]*)(?:[, ]|$)/i', array(&$this, 'parseAttributeValuePair'), $content);
 
 		$attr = $this->attr;
 
@@ -204,7 +208,7 @@ class FileMacro extends WikiMacro
 		$val = trim($matches[2]);
 
 		$size   = '/^[0-9]+(%|px|em)+$/';
-		$attrs  = '/(alt|altimage|althref|desc|title|width|height|align|border|longdesc|class|id|usemap|rel)=(.+)/';
+		$attrs  = '/(alt|altimage|althref|desc|title|width|height|align|border|longdesc|class|id|usemap|rel|details)=(.+)/';
 		$quoted = "/(?:[\"'])(.*)(?:[\"'])$/";
 
 		// Set width if just a pixel size is given
@@ -232,6 +236,26 @@ class FileMacro extends WikiMacro
 			$this->attr['href'] = 'none';
 			return;
 		}
+		// Specific call to NOT show file details
+		if ($key == 'details')
+		{
+			switch (strtolower($val))
+			{
+				case 'no':
+				case 'none':
+				case 'false':
+				case 'off':
+				case 'hide':
+				case 'hidden':
+					$this->attr['details'] = false;
+				break;
+
+				default:
+					$this->attr['details'] = true;
+				break;
+			}
+			return;
+		}
 		// Check for a specific link given
 		if ($key == 'link')
 		{
@@ -351,6 +375,13 @@ class FileMacro extends WikiMacro
 			return;
 		}
 
+		// Specific call to NOT display file metadata
+		if ($key == 'nodetails')
+		{
+			$this->attr['details'] = false;
+			return;
+		}
+
 		// Check for alignment, no key given
 		// e.g., [[File(myfile.jpg, left)]]
 		if (in_array($key, array('left', 'right', 'top', 'bottom')))
@@ -631,6 +662,7 @@ class FileMacro extends WikiMacro
 				}
 				else
 				{
+					$attr['details'] = isset($attr['details']) ? $attr['details'] : true;
 					$attr['href'] = (isset($attr['href']) && $attr['href'] != '') ? $attr['href'] : $this->_link($file);
 					$attr['rel']  = (isset($attr['rel']))  ? $attr['rel']  : 'internal';
 
@@ -644,8 +676,10 @@ class FileMacro extends WikiMacro
 						$size = filesize($this->_path($file, true));
 					}
 
-					$html = '<a class="attachment" rel="' . $attr['rel'] . '" href="' . $attr['href'] . '" title="' . $attr['alt'] . '">' . $attr['desc'] . '</a>';
-					if ($size !== null)
+					$attr['title'] = (!isset($attr['title']) || !$attr['title'] ? $attr['alt'] : $attr['title']);
+
+					$html = '<a class="attachment" rel="' . $attr['rel'] . '" href="' . $attr['href'] . '" title="' . $attr['title'] . '">' . $attr['desc'] . '</a>';
+					if ($size !== null && $attr['details'])
 					{
 						$html .= ' (<span class="file-atts">' . \Hubzero\Utility\Number::formatBytes($size);
 						if (isset($attr['created_by']))
